/////////////////////////////////////////////////////////////////////////////////////////
//
// iTead Joystick Shield Library
//
// --------------------------------------------------------------------------------------
// 
// Filename:      itead_joystick_shield.c
// Version:       1.0
// Date:          31/07/2012
// Author:        Joel Guittet - http://myfreescalewebpage.free.fr
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Revisions
//
// Version	| Author		| Description
// --------------------------------------------------------------------------------------
// 1.0      | Joel Guittet  | Initial Release
//
/////////////////////////////////////////////////////////////////////////////////////////


//---------------------------------------------------------------------------------------
// Include
//---------------------------------------------------------------------------------------

#include "itead_joystick_shield.h"


//---------------------------------------------------------------------------------------
// Name:        JOYSTICKSHIELD_Init
// Param:    	-
// Return:      -
//
// Description:	Initialization of the iTead Joystick Shield
//---------------------------------------------------------------------------------------
void JOYSTICKSHIELD_Init(void)
{
	/* Initialization of the ADC to read the axis positions */
	ADCSC1 = 0b00011111;			/* Disable the ADC */
	ADCCFG = 0b00000000;   			/* High speed configuration, short sample time, clock = bus clock, 8-bit conversion */
	SPMSC1_BGBE = 1; 				/* Enable the internal bandgap reference buffer */
	APCTL1_ADPC5 = 1;				/* AD5 used to read X axis */
	APCTL1_ADPC6 = 1;				/* AD6 used to read Y axis */
	
	/* No initialization required to read the buttons because the pins are inputs by default */
}


//---------------------------------------------------------------------------------------
// Name:        JOYSTICKSHIELD_GetStatus
// Param:    	AxisX, AxisY, ButtonA, ButtonB, ButtonC, ButtonD, ButtonE, ButtonF, ButtonG: status of the joystick and buttons
// Return:      -
//
// Description:	This functions returns the status of the joystick and buttons of the iTead Joystick Shield
//---------------------------------------------------------------------------------------
void JOYSTICKSHIELD_GetStatus(INT8 * i8AxisX, INT8 * i8AxisY, BOOLEAN * bButtonA, BOOLEAN * bButtonB, BOOLEAN * bButtonC, BOOLEAN * bButtonD, BOOLEAN * bButtonE, BOOLEAN * bButtonF, BOOLEAN * bButtonG)
{
	/* X axis */
	ADCSC1 = 5;						/* Start conversion on AD5 */
	while (!ADCSC1_COCO){}			/* Wait for conversion complete */
	*i8AxisX = ADCR - 128;			/* Result */
	
	/* Y axis */
	ADCSC1 = 6;						/* Start conversion on AD6 */
	while (!ADCSC1_COCO){}			/* Wait for conversion complete */
	*i8AxisY = ADCR - 128;			/* Result */	
			
	/* Buttons */	
	*bButtonA = !PTBD_PTBD0;
	*bButtonB = !PTDD_PTDD3;
	*bButtonC = !PTDD_PTDD4;
	*bButtonD = !PTAD_PTAD0;
	*bButtonE = !PTDD_PTDD5;
	*bButtonF = !PTAD_PTAD7;
	*bButtonG = !PTDD_PTDD2;
}
