/////////////////////////////////////////////////////////////////////////////////////////
//
// TheUno iTead Joystick Shield Library
//
// --------------------------------------------------------------------------------------
//
// Filename:      main.c
// Version:       1.0
// Date:          31/07/2012
// Author:        Joel Guittet - http://myfreescalewebpage.free.fr
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Description
//
// This project shows how to use the iTead Joystick shield available on
// http://imall.iteadstudio.com/im120417014.html
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Revisions
//
// Version	| Author		| Description
// --------------------------------------------------------------------------------------
// 1.0      | Joel Guittet  | Initial Release
//
/////////////////////////////////////////////////////////////////////////////////////////


//---------------------------------------------------------------------------------------
// Includes
//---------------------------------------------------------------------------------------

#include <hidef.h>
#include "derivative.h"
#include "typedef.h"
#include "itead_joystick_shield.h"


//---------------------------------------------------------------------------------------
// Prototypes
//---------------------------------------------------------------------------------------

static void InitCPU(void);
static void InitMCG(void);
static void InitGPIO(void);


//---------------------------------------------------------------------------------------
// Name:        main
// Param:		-
// Return:      -
//
// Description:	Main function, never return
//---------------------------------------------------------------------------------------
void main(void)
{
	INT8 i8AxisX, i8AxisY;
	BOOLEAN bButtonA, bButtonB, bButtonC, bButtonD, bButtonE, bButtonF, bButtonG;
	
	/* Initializations */
	InitCPU();
	
	/* Initialize iTead Joystick Shield */
	JOYSTICKSHIELD_Init();

	EnableInterrupts;

	/* Main loop */
	for(;;)
	{
		/* Get iTead Joystick Shield status */
		JOYSTICKSHIELD_GetStatus(&i8AxisX, &i8AxisY, &bButtonA, &bButtonB, &bButtonC, &bButtonD, &bButtonE, &bButtonF, &bButtonG);

		/* Now it is possible to use the joystick status */
		
		__RESET_WATCHDOG();
	}
}


//---------------------------------------------------------------------------------------
// Name:        InitCPU
// Param:		-
// Return:      -
//
// Description:	Initialize CPU
//---------------------------------------------------------------------------------------
static void InitCPU(void)
{
	InitMCG();
	InitGPIO();
}


//---------------------------------------------------------------------------------------
// Name:        InitMCG
// Param:    	-
// Return:      -
//
// Description:	MCG configuration: Crystal=12MHz, Fbus = 18MHz
//---------------------------------------------------------------------------------------
static void InitMCG(void)
{
	MCGC2 = 0x36;
	while(MCGSC_OSCINIT != 1);
	MCGC1 = 0xB8;
	while(MCGSC_IREFST != 0);
	while(MCGSC_CLKST != 0b10);  
	MCGC1 = 0x98;
	MCGC3 = 0x46;
	while(MCGSC_PLLST != 1);
	while(MCGSC_LOCK != 1);
	MCGC1 = 0x18;
	while(MCGSC_CLKST != 0b11);
}


//---------------------------------------------------------------------------------------
// Name:        InitGPIO
// Param:    	-
// Return:      -
//
// Description:	IO ports initialization
//---------------------------------------------------------------------------------------
static void InitGPIO(void)
{
}
